@@ -19,7 +19,7 @@ class Query():
         
     async def do_query(self, protocol : typing.Union[Get, Set]):
         data_ = protocol.query+"\r\n"
-        self.writer.write(data.encode())
+        self.writer.write(data_.encode())
         await self.writer.drain()
         data = await self.reader.read(100)
         return Result(f'{data.decode()!r}')
